pub struct RegistrationClient(pub(crate) Client);Tuple Fields
0: ClientImplementations
Sourceimpl RegistrationClient
impl RegistrationClient
Sourcepub async fn post_keys_for_tde_registration(
&self,
request: TdeRegistrationRequest,
) -> Result<TdeRegistrationResponse, BitwardenError>
pub async fn post_keys_for_tde_registration( &self, request: TdeRegistrationRequest, ) -> Result<TdeRegistrationResponse, BitwardenError>
Initializes a new cryptographic state for a user and posts it to the server; enrolls in admin password reset and finally enrolls the user to TDE unlock.
Sourcepub async fn post_keys_for_key_connector_registration(
&self,
key_connector_url: String,
sso_org_identifier: String,
) -> Result<KeyConnectorRegistrationResult, BitwardenError>
pub async fn post_keys_for_key_connector_registration( &self, key_connector_url: String, sso_org_identifier: String, ) -> Result<KeyConnectorRegistrationResult, BitwardenError>
Initializes a new cryptographic state for a user and posts it to the server; enrolls the user to key connector unlock.
Sourcepub async fn post_keys_for_jit_password_registration(
&self,
request: JitMasterPasswordRegistrationRequest,
) -> Result<JitMasterPasswordRegistrationResponse, BitwardenError>
pub async fn post_keys_for_jit_password_registration( &self, request: JitMasterPasswordRegistrationRequest, ) -> Result<JitMasterPasswordRegistrationResponse, BitwardenError>
Initializes a new cryptographic state for a user and posts it to the server; enrolls the user to master password unlock.